<template>
  <div class="p-2">
    <transition :enter-active-class="proxy?.animate.searchAnimate.enter" :leave-active-class="proxy?.animate.searchAnimate.leave">
      <div v-show="showSearch" class="mb-[10px]">
        <el-card shadow="hover">
          <el-form ref="queryFormRef" :model="queryParams" :inline="true">
            <el-form-item label="批次号" prop="batchCode">
              <el-input v-model="queryParams.batchCode" placeholder="请输入批次号" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <el-form-item label="测试序号" prop="testNum">
              <el-input v-model="queryParams.testNum" placeholder="请输入测试序号" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <el-form-item label="复测次数" prop="retestNum">
              <el-input v-model="queryParams.retestNum" placeholder="请输入复测次数" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <el-form-item label="设备号" prop="deviceCode">
              <el-input v-model="queryParams.deviceCode" placeholder="请输入设备号" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <el-form-item label="用户帐号" prop="userName">
              <el-input v-model="queryParams.userName" placeholder="请输入用户帐号" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
              <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
          </el-form>
        </el-card>
      </div>
    </transition>

    <el-card shadow="never">
      <template #header>
        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button type="primary" plain icon="Plus" @click="handleAdd" v-hasPermi="['lb-qms:sensorRetest:add']">新增</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Edit" :disabled="single" @click="handleUpdate()" v-hasPermi="['lb-qms:sensorRetest:edit']">修改</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete()" v-hasPermi="['lb-qms:sensorRetest:remove']">删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="warning" plain icon="Download" @click="handleExport" v-hasPermi="['lb-qms:sensorRetest:export']">导出</el-button>
          </el-col>
          <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>
      </template>

      <el-table
        v-loading="loading"
        :data="sensorRetestList"
        @selection-change="handleSelectionChange"
        stripe
        highlight-current-row
      >
        <el-table-column type="selection" width="55" align="center" />
        <el-table-column label="批次号" align="center" prop="batchCode" v-if="true" />
        <el-table-column label="测试序号" align="center" prop="testNum" v-if="true" />
        <el-table-column label="复测次数" align="center" prop="retestNum" v-if="true" />
        <el-table-column label="设备号" align="center" prop="deviceCode" />
        <el-table-column label="用户帐号" align="center" prop="userName" />
        <el-table-column label="判定结果" align="center" prop="judgeResult" />
        <el-table-column label="总测试项数" align="center" prop="totalCount" />
        <el-table-column label="OK项数" align="center" prop="okCount" />
        <el-table-column label="NG项数" align="center" prop="ngCount" />
        <el-table-column label="备注" align="center" prop="remark" />
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-tooltip content="修改" placement="top">
              <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)" v-hasPermi="['lb-qms:sensorRetest:edit']"></el-button>
            </el-tooltip>
            <el-tooltip content="删除" placement="top">
              <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)" v-hasPermi="['lb-qms:sensorRetest:remove']"></el-button>
            </el-tooltip>
          </template>
        </el-table-column>
      </el-table>

      <pagination v-show="total > 0" :total="total" v-model:page="queryParams.pageNum" v-model:limit="queryParams.pageSize" @pagination="getList" />
    </el-card>
    <!-- 添加或修改复测记录对话框 -->
    <el-dialog :title="dialog.title" v-model="dialog.visible" width="500px" append-to-body>
      <el-form ref="sensorRetestFormRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="设备号" prop="deviceCode">
          <el-input v-model="form.deviceCode" placeholder="请输入设备号" />
        </el-form-item>
        <el-form-item label="用户帐号" prop="userName">
          <el-input v-model="form.userName" placeholder="请输入用户帐号" />
        </el-form-item>
        <el-form-item label="判定结果" prop="judgeResult">
          <el-input v-model="form.judgeResult" placeholder="请输入判定结果" />
        </el-form-item>
        <el-form-item label="总测试项数" prop="totalCount">
          <el-input v-model="form.totalCount" placeholder="请输入总测试项数" />
        </el-form-item>
        <el-form-item label="OK项数" prop="okCount">
          <el-input v-model="form.okCount" placeholder="请输入OK项数" />
        </el-form-item>
        <el-form-item label="NG项数" prop="ngCount">
          <el-input v-model="form.ngCount" placeholder="请输入NG项数" />
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="SensorRetest" lang="ts">
import { listSensorRetest, getSensorRetest, delSensorRetest, addSensorRetest, updateSensorRetest } from '@/api/qms/sensorRetest';
import { SensorRetestVO, SensorRetestQuery, SensorRetestForm } from '@/api/qms/sensorRetest/types';

const { proxy } = getCurrentInstance() as ComponentInternalInstance;

const sensorRetestList = ref<SensorRetestVO[]>([]);
const buttonLoading = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref<Array<string | number>>([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);

const queryFormRef = ref<ElFormInstance>();
const sensorRetestFormRef = ref<ElFormInstance>();

const dialog = reactive<DialogOption>({
  visible: false,
  title: ''
});

const initFormData: SensorRetestForm = {
  batchCode: undefined,
  testNum: undefined,
  retestNum: undefined,
  deviceCode: undefined,
  userName: undefined,
  judgeResult: undefined,
  totalCount: undefined,
  okCount: undefined,
  ngCount: undefined,
  remark: undefined
}
const data = reactive<PageData<SensorRetestForm, SensorRetestQuery>>({
  form: {...initFormData},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    batchCode: undefined,
    testNum: undefined,
    retestNum: undefined,
    deviceCode: undefined,
    userName: undefined,
    params: {
    }
  },
  rules: {
    batchCode: [
      { required: true, message: "批次号不能为空", trigger: "blur" }
    ],
    testNum: [
      { required: true, message: "测试序号不能为空", trigger: "blur" }
    ],
    retestNum: [
      { required: true, message: "复测次数不能为空", trigger: "blur" }
    ],
  }
});

const { queryParams, form, rules } = toRefs(data);

/** 查询复测记录列表 */
const getList = async () => {
  loading.value = true;
  const res = await listSensorRetest(queryParams.value);
  sensorRetestList.value = res.rows;
  total.value = res.total;
  loading.value = false;
}

/** 取消按钮 */
const cancel = () => {
  reset();
  dialog.visible = false;
}

/** 表单重置 */
const reset = () => {
  form.value = {...initFormData};
  sensorRetestFormRef.value?.resetFields();
}

/** 搜索按钮操作 */
const handleQuery = () => {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
const resetQuery = () => {
  queryFormRef.value?.resetFields();
  handleQuery();
}

/** 多选框选中数据 */
const handleSelectionChange = (selection: SensorRetestVO[]) => {
  ids.value = selection.map(item => item.batchCode);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
const handleAdd = () => {
  reset();
  dialog.visible = true;
  dialog.title = "添加复测记录";
}

/** 修改按钮操作 */
const handleUpdate = async (row?: SensorRetestVO) => {
  reset();
  const _batchCode = row?.batchCode || ids.value[0]
  const res = await getSensorRetest(_batchCode);
  Object.assign(form.value, res.data);
  dialog.visible = true;
  dialog.title = "修改复测记录";
}

/** 提交按钮 */
const submitForm = () => {
  sensorRetestFormRef.value?.validate(async (valid: boolean) => {
    if (valid) {
      buttonLoading.value = true;
      if (form.value.batchCode) {
        await updateSensorRetest(form.value).finally(() =>  buttonLoading.value = false);
      } else {
        await addSensorRetest(form.value).finally(() =>  buttonLoading.value = false);
      }
      proxy?.$modal.msgSuccess("操作成功");
      dialog.visible = false;
      await getList();
    }
  });
}

/** 删除按钮操作 */
const handleDelete = async (row?: SensorRetestVO) => {
  const _batchCodes = row?.batchCode || ids.value;
  await proxy?.$modal.confirm('是否确认删除复测记录编号为"' + _batchCodes + '"的数据项？').finally(() => loading.value = false);
  await delSensorRetest(_batchCodes);
  proxy?.$modal.msgSuccess("删除成功");
  await getList();
}

/** 导出按钮操作 */
const handleExport = () => {
  proxy?.download('qms/sensorRetest/export', {
    ...queryParams.value
  }, `sensorRetest_${new Date().getTime()}.xlsx`)
}

onMounted(() => {
  getList();
});
</script>
